pub trait TowerField: BinaryField {
const TOWER_LEVEL: usize = _;
// Required method
fn min_tower_level(self) -> usize;
// Provided method
fn basis(iota: usize, i: usize) -> Self { ... }
}Expand description
A binary field isomorphic to a binary tower field.
The canonical binary field tower construction is specified in DP23, section 2.3. This is a family of binary fields with extension degree $2^{\iota}$ for any tower height $\iota$. This trait can be implemented on any binary field isomorphic to the canonical tower field.
Provided Associated Constants
Sourceconst TOWER_LEVEL: usize = _
const TOWER_LEVEL: usize = _
The level $\iota$ in the tower, where this field is isomorphic to $T_{\iota}$.
Required Methods
Sourcefn min_tower_level(self) -> usize
fn min_tower_level(self) -> usize
Returns the smallest valid TOWER_LEVEL in the tower that can fit the same value.
Since which TOWER_LEVEL values are valid depends on the tower,
F::Canonical::from(elem).min_tower_level() can return a different result
from elem.min_tower_level().
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.